@@ -2,7 +2,7 @@ use strict; use warnings;
 package TestMLBridge;
 use base 'TestML::Bridge';
 
-use YAML::XS;
+use YAML::PP;
 
 use Pegex::JSON;
 
@@ -15,10 +15,10 @@ sub load {
 
 sub yaml {
   my ($self, $str) = @_;
-  my $yaml = YAML::XS::Dump($str);
+  my $yaml = YAML::PP->new(schema => [qw'Core Perl'])->dump($str);
 
   $yaml =~ s/^---\s+//;
-  $yaml =~ s{!!perl/scalar:boolean }{};
+  $yaml =~ s{!perl/scalar:boolean\s+=: ([01])}{$1};
 
   return $yaml;
 }
